<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="sv" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../ReText/config.py" line="80"/>
        <source>Using configuration file at:</source>
        <translation>Använd konfigurationsfilen:</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Behavior</source>
        <translation>Beteende</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically save documents</source>
        <translation>Spara dokument automatiskt</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Automatically open last documents on startup</source>
        <translation>Öppna de senaste dokumenten automatiskt vid uppstart</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Number of recent documents</source>
        <translation>Antal senaste dokument</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Restore window geometry</source>
        <translation>Återställ fönsterstorlek</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Default preview state</source>
        <translation>Förvalt förhandsvisningsläge</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Open external links in ReText window</source>
        <translation>Öppna externa länkar i ReText-fönstret</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Insticksmoduler för Markdown-syntax (kommaseparerade)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>Aktivera synkroniserad rullning för Markdown</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="169"/>
        <source>Editor</source>
        <translation>Textredigerare</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Highlight current line</source>
        <translation>Markera aktuell rad</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show line numbers</source>
        <translation>Visa radnummer</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Line numbers are relative to current line</source>
        <translation>Linjenummer är i förhållande till aktuell rad</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tab key inserts spaces</source>
        <translation>Konvertera tabbar till blanksteg</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Tabulation width</source>
        <translation>Tabb-bredd</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Draw vertical line at column</source>
        <translation>Visa vertikal linje vid kolumn</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Enable soft wrap</source>
        <translation>Aktivera radbrytning</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show document stats</source>
        <translation>Visa dokumentstatistik</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Interface</source>
        <translation>Gränssnitt</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide toolbar</source>
        <translation>Dölj verktygsfält</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Icon theme name</source>
        <translation>Ikon-tema</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Stylesheet file</source>
        <translation>Stilmall</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Hide tabs bar when there is only one tab</source>
        <translation>Dölj flikfältet när det bara finns en flik</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="97"/>
        <source>Show full path in window title</source>
        <translation>Visa full sökväg i fönstertitel</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="151"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="170"/>
        <source>Live preview</source>
        <translation>Live förhandsvisning</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="171"/>
        <source>Normal preview</source>
        <translation>Normal förhandsvisning</translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="../ReText/config.py" line="35"/>
        <source>(none)</source>
        <translation>(inget)</translation>
    </message>
    <message>
        <location filename="../ReText/config.py" line="42"/>
        <source>Select file to open</source>
        <translation>Välj fil som ska öppnas</translation>
    </message>
</context>
<context>
    <name>InsertTableDialog</name>
    <message>
        <location filename="../ReText/tabledialog.py" line="27"/>
        <source>Insert table</source>
        <translation>Infoga tabell</translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="36"/>
        <source>Number of rows</source>
        <translation>Antal rader</translation>
    </message>
    <message>
        <location filename="../ReText/tabledialog.py" line="37"/>
        <source>Number of columns</source>
        <translation>Antal kolumner</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../ReText/dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Ange landsnamn (exempel: en_US)</translation>
    </message>
    <message>
        <location filename="../ReText/dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Ange som standard</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="61"/>
        <source>No write since last change (add ! to override)</source>
        <translation>Ingen överskrift av fil efter senaste ändring (lägg till ! för att tvinga överskrift)</translation>
    </message>
    <message>
        <location filename="../ReText/fakevimeditor.py" line="118"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="../ReText/editor.py" line="212"/>
        <source>Add to dictionary</source>
        <translation>Lägg till i ordboken</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Save image</source>
        <translation>Spara bild</translation>
    </message>
    <message>
        <location filename="../ReText/editor.py" line="391"/>
        <source>Images (*.png *.jpg)</source>
        <translation>Bilder (*.png *.jpg)</translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="../ReText/tab.py" line="184"/>
        <source>New document</source>
        <translation>Nytt dokument</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="189"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Misslyckades att analysera filinnehållet, kontrollera att du har installerat den &lt;a href=&quot;%s&quot;&gt;nödvändiga modulen&lt;/a&gt;!</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>Create missing file?</source>
        <translation>Skapa saknad fil?</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="478"/>
        <source>The file &apos;%s&apos; does not exist.

Do you want to create it?</source>
        <translation>Filen &apos;%s&apos; existerar inte.

Vill du skapa den?</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>File could not be created</source>
        <translation>Filen kunde inte bli skapad</translation>
    </message>
    <message>
        <location filename="../ReText/tab.py" line="511"/>
        <source>Could not create file &apos;%s&apos;: %s</source>
        <translation>Kunde inte skapa filen &apos;%s&apos;: %s</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="../ReText/window.py" line="82"/>
        <source>File toolbar</source>
        <translation>Filverktygsfält</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="84"/>
        <source>Edit toolbar</source>
        <translation>Redigeringsfält</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="86"/>
        <source>Search toolbar</source>
        <translation>Sökfält</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="90"/>
        <source>New</source>
        <translation>Nytt</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="93"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="96"/>
        <source>Set encoding</source>
        <translation>Teckenkodning</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1190"/>
        <source>Reload</source>
        <translation>Ladda om</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="102"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="106"/>
        <source>Save as</source>
        <translation>Spara som</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="108"/>
        <source>Next tab</source>
        <translation>Nästa flik</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="110"/>
        <source>Previous tab</source>
        <translation>Föregående flik</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="112"/>
        <source>Close tab</source>
        <translation>Stäng flik</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="114"/>
        <source>Print</source>
        <translation>Skriv ut</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="117"/>
        <source>Print preview</source>
        <translation>Förhandsgranska utskrift</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="119"/>
        <source>View HTML code</source>
        <translation>Visa HTML-kod</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="120"/>
        <source>Change editor font</source>
        <translation>Ändra typsnitt för redigering</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="122"/>
        <source>Change preview font</source>
        <translation>Ändra typsnitt för förhandsgranskning</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="124"/>
        <source>Find text</source>
        <translation>Hitta ord</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Go to line</source>
        <translation>Gå till linje</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="129"/>
        <source>Preview</source>
        <translation>Förhandsgranska</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="139"/>
        <source>Live preview</source>
        <translation>Live förhandsgranskning</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="144"/>
        <source>Insert table</source>
        <translation>Infoga tabell</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="146"/>
        <source>Table editing mode</source>
        <translation>Tabellredigeringsläge</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="152"/>
        <source>FakeVim mode</source>
        <translation>FakeVim-läge</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="157"/>
        <source>Fullscreen mode</source>
        <translation>Fullskärmsläge</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="630"/>
        <source>Preferences</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="168"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="171"/>
        <source>Undo</source>
        <translation>Ångra</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="173"/>
        <source>Redo</source>
        <translation>Gör om</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="175"/>
        <source>Copy</source>
        <translation>Kopiera</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="177"/>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="179"/>
        <source>Paste</source>
        <translation>Klistra in</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="181"/>
        <source>Paste image</source>
        <translation>Klistra in bild</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="183"/>
        <source>Move line up</source>
        <translation>Flytta linje upp</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="185"/>
        <source>Move line down</source>
        <translation>Flytta linje ner</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="195"/>
        <source>Enable</source>
        <translation>Aktivera</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="196"/>
        <source>Set locale</source>
        <translation>Ange lokalisering</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="197"/>
        <source>Use WebKit renderer</source>
        <translation>Använd WebKit som renderare</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="202"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation>Använd WebEngine (Chromium) som renderare</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="207"/>
        <source>Show directory</source>
        <translation>Visa ordbok</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="208"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="210"/>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="212"/>
        <source>Replace</source>
        <translation>Ersätt</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="214"/>
        <source>Replace all</source>
        <translation>Ersätt alla</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="218"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="222"/>
        <source>Get help online</source>
        <translation>Få hjälp online</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="223"/>
        <source>About ReText</source>
        <translation>Om ReText</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="226"/>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="241"/>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="243"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="245"/>
        <source>Underline</source>
        <translation>Understrykning</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="318"/>
        <source>Formatting</source>
        <translation>Formattering</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="258"/>
        <source>Symbols</source>
        <translation>Symboler</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="263"/>
        <source>File</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="264"/>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="265"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="268"/>
        <source>Open recent</source>
        <translation>Öppna senaste</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="281"/>
        <source>Export</source>
        <translation>Exportera</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="306"/>
        <source>Spell check</source>
        <translation>Stavningskontroll</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="315"/>
        <source>Default markup</source>
        <translation>Standardtyp</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="360"/>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="363"/>
        <source>Replace with</source>
        <translation>Ersätt med</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="365"/>
        <source>Case sensitively</source>
        <translation>Skiftlägeskänsligt</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="526"/>
        <source>New document</source>
        <translation>Nytt dokument</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="678"/>
        <source>Type the line number</source>
        <translation>Skriv ut radnummer</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="714"/>
        <source>Please, save the file somewhere.</source>
        <translation>Vänligen, spara filen.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="830"/>
        <source>Select one or several files to open</source>
        <translation>Välj en eller flera filer att öppna</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Supported files</source>
        <translation>Stödda filer</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>All files (*)</source>
        <translation>Alla filer (*)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="869"/>
        <source>Select file encoding from the list:</source>
        <translation>Välj filkodning från listan:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="892"/>
        <source>Plain text (*.txt)</source>
        <translation>Ren text (*.txt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="895"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s filer</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>Save file</source>
        <translation>Spara fil</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="915"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation>Kan inte spara till fil som är öppen i en annan flik!</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="938"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Kan inte spara till fil eftersom den är skrivskyddad!</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>Export document to ODT</source>
        <translation>Exportera dokument som ODT</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="960"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument textfiler (*.odt)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="970"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-dokument (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="993"/>
        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
        <translation>Kan inte läsa av inställningar för pappersstorlek &quot;%s&quot;</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>Export document to PDF</source>
        <translation>Exportera dokument som PDF</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1019"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF-filer (*.pdf)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1046"/>
        <source>Print document</source>
        <translation>Skriv ut dokument</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1069"/>
        <source>Export document</source>
        <translation>Exportera dokument</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1090"/>
        <source>Failed to execute the command:</source>
        <translation>Misslyckades med att utföra kommandot:</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1131"/>
        <source>Alt text</source>
        <translation>Alt textbild</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>URL</source>
        <translation>Webbadress URL</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1132"/>
        <source>Link text</source>
        <translation>Länktext</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1173"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Den här filen har raderats av en annan applikation.
Se till att du sparar filen innan du avslutar.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1181"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Detta dokument har ändrats av en annan applikation.
Vill du ladda om filen (det här förkastar alla dina ändringar)?
</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1186"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Om du väljer att inte ladda om filen, kommer &apos;automatisk sparläge&apos; att avaktiveras för den här sessionen för att förhindra förlust av data.</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1210"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokumentet har ändrats.
Vill du spara dina ändringar?</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1238"/>
        <source>HTML code</source>
        <translation>HTML-källkod</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s (använder PyMarkups %s)</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Enkel men kraftfull textredigerare för Markdown och reStructuredText</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Upphovsman: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Website</source>
        <translation>Hemsida</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>Markdown syntax</source>
        <translation>Markdown-syntax</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1266"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText-syntax</translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="149"/>
        <source>Insert images by file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/window.py" line="1248"/>
        <source>Select one or several images to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextInfoArea</name>
    <message>
        <location filename="../ReText/editor.py" line="582"/>
        <source>%d w | %d a | %d c</source>
        <comment>count of words, alphanumeric characters, all characters</comment>
        <translation>%d ord | %d alfanumeriska tecken | %d tecken totalt</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../ReText/__main__.py" line="77"/>
        <source>Open the files in preview mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="79"/>
        <source>Create a new window even if there is an existing one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ReText/__main__.py" line="83"/>
        <source>List of files to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
